import * as i0 from '@angular/core';
import { Input, Component, NgModule } from '@angular/core';
import { cloneDeep } from 'lodash';

/*
* (c) Copyright Ascensio System SIA 2025
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*     http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/
const loadScript = async (url, id) => {
    return new Promise((resolve, reject) => {
        try {
            // If DocsAPI is defined return resolve.
            if (window.DocsAPI)
                return resolve(null);
            const existedScript = document.getElementById(id);
            if (existedScript) {
                // If the script element is found, wait for it to load.
                let intervalHandler = setInterval(() => {
                    const loading = existedScript.getAttribute("loading");
                    if (loading) {
                        // If the download is not completed, continue to wait.
                        return;
                    }
                    else {
                        // If the download is completed, stop the wait.
                        clearInterval(intervalHandler);
                        // If DocsAPI is defined, after loading return resolve.
                        if (window.DocsAPI)
                            return resolve(null);
                        // If DocsAPI is not defined, delete the existing script and create a new one.
                        const script = _createScriptTag(id, url, resolve, reject);
                        existedScript.remove();
                        document.body.appendChild(script);
                    }
                }, 500);
            }
            else {
                // If the script element is not found, create it.
                const script = _createScriptTag(id, url, resolve, reject);
                document.body.appendChild(script);
            }
        }
        catch (e) {
            console.error(e);
        }
    });
};
const _createScriptTag = (id, url, resolve, reject) => {
    const script = document.createElement("script");
    script.id = id;
    script.type = "text/javascript";
    script.src = url;
    script.async = true;
    script.onload = () => {
        // Remove attribute loading after loading is complete.
        script.removeAttribute("loading");
        resolve(null);
    };
    script.onerror = (error) => {
        // Remove attribute loading after loading is complete.
        script.removeAttribute("loading");
        reject(error);
    };
    script.setAttribute("loading", "");
    return script;
};

/*
* (c) Copyright Ascensio System SIA 2025
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*     http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/
class DocumentEditorComponent {
    constructor() {
        this.shardkey = true;
        this.isFirstOnChanges = true;
        this.onLoad = () => {
            try {
                if (!window.DocsAPI)
                    this.onError(-3);
                if (window?.DocEditor?.instances[this.id]) {
                    console.log("Skip loading. Instance already exists", this.id);
                    return;
                }
                if (!window?.DocEditor?.instances) {
                    window.DocEditor = { instances: {} };
                }
                var cloneConfig = cloneDeep(this.config);
                var propsConfig = {
                    documentType: this.documentType,
                    events: {
                        onAppReady: this.onAppReady,
                        onDocumentStateChange: this.events_onDocumentStateChange,
                        onMetaChange: this.events_onMetaChange,
                        onDocumentReady: this.events_onDocumentReady,
                        onInfo: this.events_onInfo,
                        onWarning: this.events_onWarning,
                        onError: this.events_onError,
                        onRequestSharingSettings: this.events_onRequestSharingSettings,
                        onRequestRename: this.events_onRequestRename,
                        onMakeActionLink: this.events_onMakeActionLink,
                        onRequestInsertImage: this.events_onRequestInsertImage,
                        onRequestSaveAs: this.events_onRequestSaveAs,
                        onRequestMailMergeRecipients: this.events_onRequestMailMergeRecipients,
                        onRequestCompareFile: this.events_onRequestCompareFile,
                        onRequestEditRights: this.events_onRequestEditRights,
                        onRequestHistory: this.events_onRequestHistory,
                        onRequestHistoryClose: this.events_onRequestHistoryClose,
                        onRequestHistoryData: this.events_onRequestHistoryData,
                        onRequestRestore: this.events_onRequestRestore,
                        onRequestSelectSpreadsheet: this.events_onRequestSelectSpreadsheet,
                        onRequestSelectDocument: this.events_onRequestSelectDocument,
                        onRequestUsers: this.events_onRequestUsers
                    },
                    height: this.height,
                    type: this.type,
                    width: this.width,
                };
                const document = this.getDocument();
                const editorConfig = this.getEditorConfig();
                if (document !== null) {
                    propsConfig.document = document;
                }
                if (editorConfig !== null) {
                    propsConfig.editorConfig = editorConfig;
                }
                let initConfig = Object.assign(propsConfig, cloneConfig || {});
                const editor = window.DocsAPI.DocEditor(this.id, initConfig);
                window.DocEditor.instances[this.id] = editor;
            }
            catch (err) {
                console.error(err);
                this.onError(-1);
            }
        };
        this.getDocument = () => {
            var document = null;
            if (this.document_fileType) {
                document = document || {};
                document.fileType = this.document_fileType;
            }
            if (this.document_title) {
                document = document || {};
                document.document_title = this.document_title;
            }
            return document;
        };
        this.getEditorConfig = () => {
            var editorConfig = null;
            if (this.editorConfig_lang) {
                editorConfig = editorConfig || {};
                editorConfig.lang = this.editorConfig_lang;
            }
            return editorConfig;
        };
        this.onError = (errorCode) => {
            let message;
            switch (errorCode) {
                case -2:
                    message = "Error load DocsAPI from " + this.documentServerUrl;
                    break;
                case -3:
                    message = "DocsAPI is not defined";
                    break;
                default:
                    message = "Unknown error loading component";
                    errorCode = -1;
            }
            if (typeof this.onLoadComponentError == "undefined") {
                console.error(message);
            }
            else {
                this.onLoadComponentError(errorCode, message);
            }
        };
    }
    ngOnInit() {
        let url = this.documentServerUrl;
        if (!url.endsWith("/"))
            url += "/";
        let docsApiUrl = `${url}web-apps/apps/api/documents/api.js`;
        if (this.shardkey) {
            if (typeof this.shardkey === "boolean") {
                docsApiUrl += `?shardkey=${this.config.document?.key}`;
            }
            else {
                docsApiUrl += `?shardkey=${this.shardkey}`;
            }
        }
        loadScript(docsApiUrl, "onlyoffice-api-script")
            .then(() => this.onLoad())
            .catch((err) => {
            this.onError(-2);
        });
    }
    ngOnChanges(changes) {
        const listNameChanges = ["config", "document_fileType", "document_title", "documentType", "editorConfig_lang", "height", "type", "width"];
        if (this.isFirstOnChanges) {
            this.isFirstOnChanges = false;
            return;
        }
        for (const name of listNameChanges) {
            if (changes.hasOwnProperty(name)) {
                if (window?.DocEditor?.instances[this.id]) {
                    window.DocEditor.instances[this.id].destroyEditor();
                    window.DocEditor.instances[this.id] = undefined;
                    console.log("Important props have been changed. Load new Editor.");
                    this.onLoad();
                    return;
                }
            }
        }
    }
    ngOnDestroy() {
        if (window?.DocEditor?.instances[this.id]) {
            window.DocEditor.instances[this.id].destroyEditor();
            window.DocEditor.instances[this.id] = undefined;
        }
    }
    onAppReady() {
        this.events_onAppReady(window.DocEditor.instances[this.id]);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: DocumentEditorComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.2.3", type: DocumentEditorComponent, isStandalone: false, selector: "document-editor", inputs: { id: "id", documentServerUrl: "documentServerUrl", shardkey: "shardkey", config: "config", document_fileType: "document_fileType", document_title: "document_title", documentType: "documentType", editorConfig_lang: "editorConfig_lang", height: "height", type: "type", width: "width", onLoadComponentError: "onLoadComponentError", events_onAppReady: "events_onAppReady", events_onDocumentStateChange: "events_onDocumentStateChange", events_onMetaChange: "events_onMetaChange", events_onDocumentReady: "events_onDocumentReady", events_onInfo: "events_onInfo", events_onWarning: "events_onWarning", events_onError: "events_onError", events_onRequestSharingSettings: "events_onRequestSharingSettings", events_onRequestRename: "events_onRequestRename", events_onMakeActionLink: "events_onMakeActionLink", events_onRequestInsertImage: "events_onRequestInsertImage", events_onRequestSaveAs: "events_onRequestSaveAs", events_onRequestMailMergeRecipients: "events_onRequestMailMergeRecipients", events_onRequestCompareFile: "events_onRequestCompareFile", events_onRequestEditRights: "events_onRequestEditRights", events_onRequestHistory: "events_onRequestHistory", events_onRequestHistoryClose: "events_onRequestHistoryClose", events_onRequestHistoryData: "events_onRequestHistoryData", events_onRequestRestore: "events_onRequestRestore", events_onRequestSelectSpreadsheet: "events_onRequestSelectSpreadsheet", events_onRequestSelectDocument: "events_onRequestSelectDocument", events_onRequestUsers: "events_onRequestUsers" }, usesOnChanges: true, ngImport: i0, template: '<div [id]="id"></div>', isInline: true }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: DocumentEditorComponent, decorators: [{
            type: Component,
            args: [{ selector: 'document-editor', template: '<div [id]="id"></div>', standalone: false }]
        }], ctorParameters: () => [], propDecorators: { id: [{
                type: Input
            }], documentServerUrl: [{
                type: Input
            }], shardkey: [{
                type: Input
            }], config: [{
                type: Input
            }], document_fileType: [{
                type: Input
            }], document_title: [{
                type: Input
            }], documentType: [{
                type: Input
            }], editorConfig_lang: [{
                type: Input
            }], height: [{
                type: Input
            }], type: [{
                type: Input
            }], width: [{
                type: Input
            }], onLoadComponentError: [{
                type: Input
            }], events_onAppReady: [{
                type: Input
            }], events_onDocumentStateChange: [{
                type: Input
            }], events_onMetaChange: [{
                type: Input
            }], events_onDocumentReady: [{
                type: Input
            }], events_onInfo: [{
                type: Input
            }], events_onWarning: [{
                type: Input
            }], events_onError: [{
                type: Input
            }], events_onRequestSharingSettings: [{
                type: Input
            }], events_onRequestRename: [{
                type: Input
            }], events_onMakeActionLink: [{
                type: Input
            }], events_onRequestInsertImage: [{
                type: Input
            }], events_onRequestSaveAs: [{
                type: Input
            }], events_onRequestMailMergeRecipients: [{
                type: Input
            }], events_onRequestCompareFile: [{
                type: Input
            }], events_onRequestEditRights: [{
                type: Input
            }], events_onRequestHistory: [{
                type: Input
            }], events_onRequestHistoryClose: [{
                type: Input
            }], events_onRequestHistoryData: [{
                type: Input
            }], events_onRequestRestore: [{
                type: Input
            }], events_onRequestSelectSpreadsheet: [{
                type: Input
            }], events_onRequestSelectDocument: [{
                type: Input
            }], events_onRequestUsers: [{
                type: Input
            }] } });

/*
* (c) Copyright Ascensio System SIA 2025
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*     http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/
class DocumentEditorModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: DocumentEditorModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.2.3", ngImport: i0, type: DocumentEditorModule, declarations: [DocumentEditorComponent], exports: [DocumentEditorComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: DocumentEditorModule }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: DocumentEditorModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [
                        DocumentEditorComponent
                    ],
                    imports: [],
                    exports: [
                        DocumentEditorComponent
                    ]
                }]
        }] });

/*
* (c) Copyright Ascensio System SIA 2025
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*     http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

/*
* (c) Copyright Ascensio System SIA 2025
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*     http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/
/*
 * Public API Surface of @onlyoffice/document-editor-angular
 */

/**
 * Generated bundle index. Do not edit.
 */

export { DocumentEditorComponent, DocumentEditorModule };
//# sourceMappingURL=onlyoffice-document-editor-angular.mjs.map
